var __defProp = Object.defineProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};

// src/Adaptor.js
var Adaptor_exports = {};
__export(Adaptor_exports, {
  alterState: () => alterState,
  dataPath: () => dataPath,
  dataValue: () => dataValue,
  each: () => each,
  execute: () => execute,
  field: () => field,
  fields: () => fields,
  fn: () => fn,
  fnIf: () => fnIf,
  lastReferenceValue: () => lastReferenceValue,
  merge: () => merge,
  send: () => send,
  sourceValue: () => sourceValue
});
import {
  execute as commonExecute,
  expandReferences
} from "@openfn/language-common";
import request from "request";
import {
  field,
  fields,
  sourceValue,
  fn,
  fnIf,
  alterState,
  each,
  merge,
  dataPath,
  dataValue,
  lastReferenceValue
} from "@openfn/language-common";
function execute(...operations) {
  const initialState = {
    references: [],
    data: null
  };
  return (state) => {
    return commonExecute(...operations)({ ...initialState, ...state });
  };
}
function send(params) {
  return (state) => {
    const { recipient, sender, text, smsId } = expandReferences(params)(state);
    const { systemId, password, clientHost, inboxId } = state.configuration;
    const url = `${clientHost}/smpp/${inboxId}/send`;
    const body = { recipient, sender, text, smsId };
    const auth = {
      username: systemId,
      password
    };
    function assembleError({ response, error }) {
      if (response && [200, 201, 202, 204].indexOf(response.statusCode) > -1)
        return false;
      if (error)
        return error;
      return new Error(`Server responded with ${response.statusCode}`);
    }
    console.log("Sending message... " + url);
    console.log("With body: " + JSON.stringify(body, null, 2));
    return new Promise((resolve, reject) => {
      request.post(
        {
          url,
          json: body,
          auth
        },
        function(err, response, body2) {
          const error = assembleError({ error: err, response });
          if (error) {
            reject(error);
          } else {
            console.log(
              "Message sent to SMPP server: " + response.statusCode + "/" + response.statusMessage
            );
            resolve(response);
          }
        }
      );
    }).then((data) => {
      const nextState = { ...state, response: { body: data } };
      return nextState;
    });
  };
}

// src/index.js
var src_default = Adaptor_exports;
export {
  alterState,
  dataPath,
  dataValue,
  src_default as default,
  each,
  execute,
  field,
  fields,
  fn,
  fnIf,
  lastReferenceValue,
  merge,
  send,
  sourceValue
};
